import 'dart:async';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class PerforatedBottomNavigationBar extends StatefulWidget {
  static const MethodChannel _channel =
      const MethodChannel('perforated_bottom_navigation_bar');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  final Widget body;
  final PreferredSizeWidget appBar;
  final List<IconData> icons;

  PerforatedBottomNavigationBar({this.body, this.appBar, this.icons});

  @override
  State<StatefulWidget> createState() => _PerforatedBottomNavigationBarState();
}

class _PerforatedBottomNavigationBarState
    extends State<PerforatedBottomNavigationBar> {
  int _index = 2;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: widget.appBar,
      body: widget.appBar,
      floatingActionButton: FloatingActionButton(
        onPressed: () => _tabSelected(2),
        tooltip: 'خانه',
        child: Icon(
          widget.icons[2],
          size: 35,
          color: Colors.white,
        ),
        elevation: 2.0,
      ),
      bottomNavigationBar: BottomAppBar(
        shape: CircularNotchedRectangle(),
        elevation: 15.0,
        child: Container(
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceAround,
            children: [
              IconButton(
                icon: Icon(
                  widget.icons[4],
                  color: Theme.of(context).iconTheme.color,
                ),
                onPressed: () => _tabSelected(4),
                padding: EdgeInsets.all(0.0),
                tooltip: 'فاکتورها',
                iconSize: _index == 4 ? 30 : 25,
              ),
              IconButton(
                icon: Icon(
                  widget.icons[3],
                  color: Theme.of(context).iconTheme.color,
                ),
                onPressed: () => _tabSelected(3),
                padding: EdgeInsets.all(0.0),
                tooltip: 'سفارشات بازی',
                iconSize: _index == 3 ? 30 : 25,
              ),
              SizedBox(
                width: MediaQuery.of(context).size.width / 5,
              ),
              IconButton(
                icon: Icon(
                  widget.icons[1],
                  color: Theme.of(context).iconTheme.color,
                ),
                onPressed: () => _tabSelected(1),
                padding: EdgeInsets.all(0.0),
                tooltip: 'علاقه‌مندی‌ها',
                iconSize: _index == 1 ? 30 : 25,
              ),
              IconButton(
                icon: Icon(
                  widget.icons[0],
                  color: Theme.of(context).iconTheme.color,
                ),
                onPressed: () => _tabSelected(0),
                padding: EdgeInsets.all(0.0),
                tooltip: 'تنظیمات',
                iconSize: _index == 0 ? 30 : 25,
              ),
            ],
          ),
        ),
      ),
      floatingActionButtonLocation: FloatingActionButtonLocation.centerDocked,
    );
  }

  _tabSelected(int index) {
    setState(() {
      _index = index;
    });
  }
}
